==> dokuwiki_0.0.20080505.orig.tar.gz: dokuwiki-2008-05-05/lib/plugins/plugin/lang/ro/lang.php <==
<?php
/**
 * Romanian language file
 *
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 */
$lang['menu']                  = 'Administrează plugin-uri';
$lang['download']              = 'Descarcă şi instalează un nou plugin';
$lang['manage']                = 'Plugin-uri instalate';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizare';
$lang['btn_delete']            = 'ştergere';
$lang['btn_settings']          = 'setări';
$lang['btn_download']          = 'Descarcă';
$lang['btn_enable']            = 'Salvează';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalat:';
$lang['lastupdate']            = 'Ultima actualizare:';
$lang['source']                = 'Sursa:';
$lang['unknown']               = 'necunoscut';
$lang['updating']              = 'Se actualizează ...';
$lang['updated']               = 'Plugin-ul %s a fost actualizat cu succes';
$lang['updates']               = 'Următoarele plugin-uri au fost actualizate cu succes';
$lang['update_none']           = 'Nu a fost găsită nici o actualizare.';
$lang['deleting']              = 'Se şterge ...';
$lang['deleted']               = 'Plugin-ul %s a fost şters.';
$lang['downloading']           = 'Se descarcă ...';
$lang['downloaded']            = 'Plugin-ul %s a fost instalat cu succes';
$lang['downloads']             = 'Următoarele plugin-uri au fost instalate cu succes';
$lang['download_none']         = 'Nici un plugin nu a fost găsit, sau o problemă necunoscută a apărut în timpul descărcării şi instalării.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componente';
$lang['noinfo']                = 'Acest plugin nu a furnizat nici o informaţie; ar putea fi invalid.';
$lang['name']                  = 'Nume:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tip:';
$lang['desc']                  = 'Descriere:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'A intervenit o eroare necunoscută.';
$lang['error_download']        = 'Nu a fost posibilă descărcarea plugin-ului: %s';
$lang['error_badurl']          = 'url suspectat ca fiind eronat - nu a putut fi determinat numele fişierului din url';
$lang['error_dircreate']       = 'Nu a putut fi creat directorul temporar pentru descărcarea fişierului';
$lang['error_decompress']      = 'Administratorul de plugin-uri nu a putut dezarhiva fişierul descărcat. Aceasta se poate datora unei erori la descărcare, caz în care trebuie să încercaţi din nou; sau formatul de arhivare este necunoscut, caz în care va trebui să descărcaţi şi să instalaţi plugin-ul manual.';
$lang['error_copy']            = 'O eroare la copiere a apărut la instalarea fişierelor plugin-ului <em>%s</em>: discul poate fi plin sau drepturile de acces ale fişierelor sunt incorecte. Aceasta poate avea ca rezultat o instalare parţială a plugin-ului şi o instabilitate a instalării wiki.';
$lang['error_delete']          = 'O eroare a apărut la ştergerea plugin-ului <em>%s</em>. Cea mai probabilă cauză sunt drepturile de acces insuficiente ale fişierului sau directorului.';

==> dokuwiki_0.0.20090214b.orig.tar.gz: dokuwiki-2009-02-14/lib/plugins/plugin/lang/ro/lang.php <==
<?php
/**
 * Romanian language file
 *
 * @author Sergiu Baltariu <s_baltariu@yahoo.com>
 * @author s_baltariu@yahoo.com
 * @author Emanuel-Emeric Andrasi <n30@mandrivausers.ro>
 */
$lang['menu']                  = 'Administrează plugin-uri';
$lang['download']              = 'Descarcă şi instalează un nou plugin';
$lang['manage']                = 'Plugin-uri instalate';
$lang['btn_info']              = 'info';
$lang['btn_update']            = 'actualizare';
$lang['btn_delete']            = 'ştergere';
$lang['btn_settings']          = 'setări';
$lang['btn_download']          = 'Descarcă';
$lang['btn_enable']            = 'Salvează';
$lang['url']                   = 'URL';
$lang['installed']             = 'Instalat:';
$lang['lastupdate']            = 'Ultima actualizare:';
$lang['source']                = 'Sursa:';
$lang['unknown']               = 'necunoscut';
$lang['updating']              = 'Se actualizează ...';
$lang['updated']               = 'Plugin-ul %s a fost actualizat cu succes';
$lang['updates']               = 'Următoarele plugin-uri au fost actualizate cu succes';
$lang['update_none']           = 'Nu a fost găsită nici o actualizare.';
$lang['deleting']              = 'Se şterge ...';
$lang['deleted']               = 'Plugin-ul %s a fost şters.';
$lang['downloading']           = 'Se descarcă ...';
$lang['downloaded']            = 'Plugin-ul %s a fost instalat cu succes';
$lang['downloads']             = 'Următoarele plugin-uri au fost instalate cu succes';
$lang['download_none']         = 'Nici un plugin nu a fost găsit, sau o problemă necunoscută a apărut în timpul descărcării şi instalării.';
$lang['plugin']                = 'Plugin:';
$lang['components']            = 'Componente';
$lang['noinfo']                = 'Acest plugin nu a furnizat nici o informaţie; ar putea fi invalid.';
$lang['name']                  = 'Nume:';
$lang['date']                  = 'Data:';
$lang['type']                  = 'Tip:';
$lang['desc']                  = 'Descriere:';
$lang['author']                = 'Autor:';
$lang['www']                   = 'Web:';
$lang['error']                 = 'A intervenit o eroare necunoscută.';
$lang['error_download']        = 'Nu a fost posibilă descărcarea plugin-ului: %s';
$lang['error_badurl']          = 'url suspectat ca fiind eronat - nu a putut fi determinat numele fişierului din url';
$lang['error_dircreate']       = 'Nu a putut fi creat directorul temporar pentru descărcarea fişierului';
$lang['error_decompress']      = 'Administratorul de plugin-uri nu a putut dezarhiva fişierul descărcat. Aceasta se poate datora unei erori la descărcare, caz în care trebuie să încercaţi din nou; sau formatul de arhivare este necunoscut, caz în care va trebui să descărcaţi şi să instalaţi plugin-ul manual.';
$lang['error_copy']            = 'O eroare la copiere a apărut la instalarea fişierelor plugin-ului <em>%s</em>: discul poate fi plin sau drepturile de acces ale fişierelor sunt incorecte. Aceasta poate avea ca rezultat o instalare parţială a plugin-ului şi o instabilitate a instalării wiki.';
$lang['error_delete']          = 'O eroare a apărut la ştergerea plugin-ului <em>%s</em>. Cea mai probabilă cauză sunt drepturile de acces insuficiente ale fişierului sau directorului.';
$lang['enabled']               = 'Plugin %s activat.';
$lang['notenabled']            = 'Plugin-ul %s nu poate fi activat, verificaţi permisiunile fişierului.';
$lang['disabled']              = 'Plugin %s dezactivat.';
$lang['notdisabled']           = 'Plugin-ul %s nu poate fi dezactivat, verificaţi permisiunile fişierului.';
